# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401


class TemplateSummarySummaryNotificationRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'kind': 'TemplateKind',
        'template_meta_name': 'str',
        'name': 'str',
        'description': 'str',
        'endpoint_template_meta_name': 'str',
        'endpoint_id': 'str',
        'endpoint_type': 'str',
        'every': 'str',
        'offset': 'str',
        'message_template': 'str',
        'status': 'str',
        'status_rules': 'list[TemplateSummarySummaryStatusRules]',
        'tag_rules': 'list[TemplateSummarySummaryTagRules]',
        'label_associations': 'list[TemplateSummaryLabel]',
        'env_references': 'list[object]'
    }

    attribute_map = {
        'kind': 'kind',
        'template_meta_name': 'templateMetaName',
        'name': 'name',
        'description': 'description',
        'endpoint_template_meta_name': 'endpointTemplateMetaName',
        'endpoint_id': 'endpointID',
        'endpoint_type': 'endpointType',
        'every': 'every',
        'offset': 'offset',
        'message_template': 'messageTemplate',
        'status': 'status',
        'status_rules': 'statusRules',
        'tag_rules': 'tagRules',
        'label_associations': 'labelAssociations',
        'env_references': 'envReferences'
    }

    def __init__(self, kind=None, template_meta_name=None, name=None, description=None, endpoint_template_meta_name=None, endpoint_id=None, endpoint_type=None, every=None, offset=None, message_template=None, status=None, status_rules=None, tag_rules=None, label_associations=None, env_references=None):  # noqa: E501,D401,D403
        """TemplateSummarySummaryNotificationRules - a model defined in OpenAPI."""  # noqa: E501
        self._kind = None
        self._template_meta_name = None
        self._name = None
        self._description = None
        self._endpoint_template_meta_name = None
        self._endpoint_id = None
        self._endpoint_type = None
        self._every = None
        self._offset = None
        self._message_template = None
        self._status = None
        self._status_rules = None
        self._tag_rules = None
        self._label_associations = None
        self._env_references = None
        self.discriminator = None

        if kind is not None:
            self.kind = kind
        if template_meta_name is not None:
            self.template_meta_name = template_meta_name
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if endpoint_template_meta_name is not None:
            self.endpoint_template_meta_name = endpoint_template_meta_name
        if endpoint_id is not None:
            self.endpoint_id = endpoint_id
        if endpoint_type is not None:
            self.endpoint_type = endpoint_type
        if every is not None:
            self.every = every
        if offset is not None:
            self.offset = offset
        if message_template is not None:
            self.message_template = message_template
        if status is not None:
            self.status = status
        if status_rules is not None:
            self.status_rules = status_rules
        if tag_rules is not None:
            self.tag_rules = tag_rules
        if label_associations is not None:
            self.label_associations = label_associations
        if env_references is not None:
            self.env_references = env_references

    @property
    def kind(self):
        """Get the kind of this TemplateSummarySummaryNotificationRules.

        :return: The kind of this TemplateSummarySummaryNotificationRules.
        :rtype: TemplateKind
        """  # noqa: E501
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Set the kind of this TemplateSummarySummaryNotificationRules.

        :param kind: The kind of this TemplateSummarySummaryNotificationRules.
        :type: TemplateKind
        """  # noqa: E501
        self._kind = kind

    @property
    def template_meta_name(self):
        """Get the template_meta_name of this TemplateSummarySummaryNotificationRules.

        :return: The template_meta_name of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._template_meta_name

    @template_meta_name.setter
    def template_meta_name(self, template_meta_name):
        """Set the template_meta_name of this TemplateSummarySummaryNotificationRules.

        :param template_meta_name: The template_meta_name of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._template_meta_name = template_meta_name

    @property
    def name(self):
        """Get the name of this TemplateSummarySummaryNotificationRules.

        :return: The name of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._name

    @name.setter
    def name(self, name):
        """Set the name of this TemplateSummarySummaryNotificationRules.

        :param name: The name of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._name = name

    @property
    def description(self):
        """Get the description of this TemplateSummarySummaryNotificationRules.

        :return: The description of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._description

    @description.setter
    def description(self, description):
        """Set the description of this TemplateSummarySummaryNotificationRules.

        :param description: The description of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._description = description

    @property
    def endpoint_template_meta_name(self):
        """Get the endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.

        :return: The endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._endpoint_template_meta_name

    @endpoint_template_meta_name.setter
    def endpoint_template_meta_name(self, endpoint_template_meta_name):
        """Set the endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.

        :param endpoint_template_meta_name: The endpoint_template_meta_name of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._endpoint_template_meta_name = endpoint_template_meta_name

    @property
    def endpoint_id(self):
        """Get the endpoint_id of this TemplateSummarySummaryNotificationRules.

        :return: The endpoint_id of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._endpoint_id

    @endpoint_id.setter
    def endpoint_id(self, endpoint_id):
        """Set the endpoint_id of this TemplateSummarySummaryNotificationRules.

        :param endpoint_id: The endpoint_id of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._endpoint_id = endpoint_id

    @property
    def endpoint_type(self):
        """Get the endpoint_type of this TemplateSummarySummaryNotificationRules.

        :return: The endpoint_type of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._endpoint_type

    @endpoint_type.setter
    def endpoint_type(self, endpoint_type):
        """Set the endpoint_type of this TemplateSummarySummaryNotificationRules.

        :param endpoint_type: The endpoint_type of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._endpoint_type = endpoint_type

    @property
    def every(self):
        """Get the every of this TemplateSummarySummaryNotificationRules.

        :return: The every of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._every

    @every.setter
    def every(self, every):
        """Set the every of this TemplateSummarySummaryNotificationRules.

        :param every: The every of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._every = every

    @property
    def offset(self):
        """Get the offset of this TemplateSummarySummaryNotificationRules.

        :return: The offset of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Set the offset of this TemplateSummarySummaryNotificationRules.

        :param offset: The offset of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._offset = offset

    @property
    def message_template(self):
        """Get the message_template of this TemplateSummarySummaryNotificationRules.

        :return: The message_template of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._message_template

    @message_template.setter
    def message_template(self, message_template):
        """Set the message_template of this TemplateSummarySummaryNotificationRules.

        :param message_template: The message_template of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._message_template = message_template

    @property
    def status(self):
        """Get the status of this TemplateSummarySummaryNotificationRules.

        :return: The status of this TemplateSummarySummaryNotificationRules.
        :rtype: str
        """  # noqa: E501
        return self._status

    @status.setter
    def status(self, status):
        """Set the status of this TemplateSummarySummaryNotificationRules.

        :param status: The status of this TemplateSummarySummaryNotificationRules.
        :type: str
        """  # noqa: E501
        self._status = status

    @property
    def status_rules(self):
        """Get the status_rules of this TemplateSummarySummaryNotificationRules.

        :return: The status_rules of this TemplateSummarySummaryNotificationRules.
        :rtype: list[TemplateSummarySummaryStatusRules]
        """  # noqa: E501
        return self._status_rules

    @status_rules.setter
    def status_rules(self, status_rules):
        """Set the status_rules of this TemplateSummarySummaryNotificationRules.

        :param status_rules: The status_rules of this TemplateSummarySummaryNotificationRules.
        :type: list[TemplateSummarySummaryStatusRules]
        """  # noqa: E501
        self._status_rules = status_rules

    @property
    def tag_rules(self):
        """Get the tag_rules of this TemplateSummarySummaryNotificationRules.

        :return: The tag_rules of this TemplateSummarySummaryNotificationRules.
        :rtype: list[TemplateSummarySummaryTagRules]
        """  # noqa: E501
        return self._tag_rules

    @tag_rules.setter
    def tag_rules(self, tag_rules):
        """Set the tag_rules of this TemplateSummarySummaryNotificationRules.

        :param tag_rules: The tag_rules of this TemplateSummarySummaryNotificationRules.
        :type: list[TemplateSummarySummaryTagRules]
        """  # noqa: E501
        self._tag_rules = tag_rules

    @property
    def label_associations(self):
        """Get the label_associations of this TemplateSummarySummaryNotificationRules.

        :return: The label_associations of this TemplateSummarySummaryNotificationRules.
        :rtype: list[TemplateSummaryLabel]
        """  # noqa: E501
        return self._label_associations

    @label_associations.setter
    def label_associations(self, label_associations):
        """Set the label_associations of this TemplateSummarySummaryNotificationRules.

        :param label_associations: The label_associations of this TemplateSummarySummaryNotificationRules.
        :type: list[TemplateSummaryLabel]
        """  # noqa: E501
        self._label_associations = label_associations

    @property
    def env_references(self):
        """Get the env_references of this TemplateSummarySummaryNotificationRules.

        :return: The env_references of this TemplateSummarySummaryNotificationRules.
        :rtype: list[object]
        """  # noqa: E501
        return self._env_references

    @env_references.setter
    def env_references(self, env_references):
        """Set the env_references of this TemplateSummarySummaryNotificationRules.

        :param env_references: The env_references of this TemplateSummarySummaryNotificationRules.
        :type: list[object]
        """  # noqa: E501
        self._env_references = env_references

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, TemplateSummarySummaryNotificationRules):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other
