# coding: utf-8

"""
InfluxDB OSS API Service.

The InfluxDB v2 API provides a programmatic interface for all interactions with InfluxDB. Access the InfluxDB API using the `/api/v2/` endpoint.   # noqa: E501

OpenAPI spec version: 2.0.0
Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

from influxdb_client.domain.threshold_base import ThresholdBase


class RangeThreshold(ThresholdBase):
    """NOTE: This class is auto generated by OpenAPI Generator.

    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'min': 'float',
        'max': 'float',
        'within': 'bool',
        'level': 'CheckStatusLevel',
        'all_values': 'bool'
    }

    attribute_map = {
        'type': 'type',
        'min': 'min',
        'max': 'max',
        'within': 'within',
        'level': 'level',
        'all_values': 'allValues'
    }

    def __init__(self, type="range", min=None, max=None, within=None, level=None, all_values=None):  # noqa: E501,D401,D403
        """RangeThreshold - a model defined in OpenAPI."""  # noqa: E501
        ThresholdBase.__init__(self, level=level, all_values=all_values)  # noqa: E501

        self._type = None
        self._min = None
        self._max = None
        self._within = None
        self.discriminator = None

        self.type = type
        self.min = min
        self.max = max
        self.within = within

    @property
    def type(self):
        """Get the type of this RangeThreshold.

        :return: The type of this RangeThreshold.
        :rtype: str
        """  # noqa: E501
        return self._type

    @type.setter
    def type(self, type):
        """Set the type of this RangeThreshold.

        :param type: The type of this RangeThreshold.
        :type: str
        """  # noqa: E501
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self._type = type

    @property
    def min(self):
        """Get the min of this RangeThreshold.

        :return: The min of this RangeThreshold.
        :rtype: float
        """  # noqa: E501
        return self._min

    @min.setter
    def min(self, min):
        """Set the min of this RangeThreshold.

        :param min: The min of this RangeThreshold.
        :type: float
        """  # noqa: E501
        if min is None:
            raise ValueError("Invalid value for `min`, must not be `None`")  # noqa: E501
        self._min = min

    @property
    def max(self):
        """Get the max of this RangeThreshold.

        :return: The max of this RangeThreshold.
        :rtype: float
        """  # noqa: E501
        return self._max

    @max.setter
    def max(self, max):
        """Set the max of this RangeThreshold.

        :param max: The max of this RangeThreshold.
        :type: float
        """  # noqa: E501
        if max is None:
            raise ValueError("Invalid value for `max`, must not be `None`")  # noqa: E501
        self._max = max

    @property
    def within(self):
        """Get the within of this RangeThreshold.

        :return: The within of this RangeThreshold.
        :rtype: bool
        """  # noqa: E501
        return self._within

    @within.setter
    def within(self, within):
        """Set the within of this RangeThreshold.

        :param within: The within of this RangeThreshold.
        :type: bool
        """  # noqa: E501
        if within is None:
            raise ValueError("Invalid value for `within`, must not be `None`")  # noqa: E501
        self._within = within

    def to_dict(self):
        """Return the model properties as a dict."""
        result = {}

        for attr, _ in self.openapi_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Return the string representation of the model."""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`."""
        return self.to_str()

    def __eq__(self, other):
        """Return true if both objects are equal."""
        if not isinstance(other, RangeThreshold):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Return true if both objects are not equal."""
        return not self == other
